@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,9 +31,7 @@
 #include <sfx2/docfile.hxx>
 #include <vcl/svapp.hxx>
 #include <editeng/outliner.hxx>
-#ifndef _SVXLINK_HXX
 #include <sfx2/linkmgr.hxx>
-#endif
 #include <svx/svdotext.hxx>
 #include <tools/urlobj.hxx>
 #include <editeng/outlobj.hxx>
@@ -47,9 +46,7 @@
 #include "glob.hrc"
 #include "drawdoc.hxx"
 #include "stlpool.hxx"
-//#include "sdiocmpt.hxx"
 #include "pglink.hxx"
-//#include "strmname.h"
 #include "anminfo.hxx"
 
 #include "../ui/inc/strings.hrc"
@@ -316,9 +313,9 @@ void SdPage::SetModel(SdrModel* pNewModel)
 |*
 \************************************************************************/
 
-FASTBOOL SdPage::IsReadOnly() const
+bool SdPage::IsReadOnly() const
 {
-    return FALSE;
+    return false;
 }
 
 /*************************************************************************
@@ -646,3 +643,5 @@ void SdPage::removeAnnotation( const Reference< XAnnotation >& xAnnotation )
         NotifyDocumentEvent( static_cast< SdDrawDocument* >( pModel ), rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "OnAnnotationRemoved" ) ), xSource );
     }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
