@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -31,11 +32,9 @@
 #include <com/sun/star/embed/XEmbedPersist.hpp>
 #include <com/sun/star/embed/ElementModes.hpp>
 #include <com/sun/star/lang/XComponent.hpp>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
 #include <unotools/ucbstreamhelper.hxx>
-#ifndef _UNTOOLS_TEMPFILE_HXX
 #include <unotools/tempfile.hxx>
-#endif
 #include <editeng/eeitem.hxx>
 #include <editeng/flditem.hxx>
 #include <svx/svdpagv.hxx>
@@ -55,9 +54,6 @@
 #include <svl/urlbmk.hxx>
 #include <editeng/outliner.hxx>
 
-//#ifndef _SVDETC_HXX //autogen
-//#include <svx/svdetc.hxx>
-//#endif
 #include <com/sun/star/form/FormButtonType.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <unotools/streamwrap.hxx>
@@ -144,7 +140,7 @@ SdTransferable::~SdTransferable()
     if( mpSdView )
         EndListening( *const_cast< sd::View *>( mpSdView) );
 
-    Application::GetSolarMutex().acquire();
+    SolarMutexGuard aSolarGuard;
 
     ObjectReleased();
 
@@ -175,7 +171,6 @@ SdTransferable::~SdTransferable()
     delete mpVDev;
     delete mpObjDesc;
 
-    Application::GetSolarMutex().release();
 }
 
 // -----------------------------------------------------------------------------
@@ -879,3 +874,5 @@ sal_Bool SdTransferable::SetTableRTF( SdDrawDocument* pModel, const DataFlavor&
 
     return sal_False;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
