@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -31,16 +32,10 @@
 #include "DrawViewShell.hxx"
 #include <com/sun/star/embed/EmbedMisc.hpp>
 #include <svl/aeitem.hxx>
-#ifndef _SVXIDS_HRC //autogen
 #include <svx/svxids.hrc>
-#endif
-#ifndef _GLOBL3D_HXX //autogen
 #include <svx/globl3d.hxx>
-#endif
 #include <editeng/eeitem.hxx>
-#ifndef _FLDITEM_HXX
 #include <editeng/flditem.hxx>
-#endif
 #include <svx/svdogrp.hxx>
 #include <svx/svdograf.hxx>
 #include <svx/svdoole2.hxx>
@@ -567,3 +562,5 @@ void DrawViewShell::GetMenuStateSel( SfxItemSet &rSet )
 
 
 } // end of namespace sd
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
