@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -2040,31 +2041,6 @@ IMPL_LINK(OutlineView, PaintingFirstLineHdl, PaintFirstLineInfo*, pInfo)
     return 0;
 }
 
-#if 0
-sal_Int32 OutlineView::GetPageNumberWidthPixel()
-{
-    Window* pActWin = mpOutlineViewShell->GetActiveWindow();
-    if( pActWin )
-    {
-        Font aOldFont( pActWin->GetFont() );
-        pActWin->SetFont( maPageNumberFont );
-        Size aSize( pActWin->GetTextWidth( String( RTL_CONSTASCII_USTRINGPARAM("X" ) ) ), 0 );
-        sal_Int32 nWidth = pActWin->LogicToPixel( aSize ).Width() * 5;
-
-        const String aBulletStr( sal_Unicode( 0xE011 ) );
-        pActWin->SetFont( maBulletFont);
-
-        aSize.Width() = pActWin->GetTextWidth(aBulletStr);
-        nWidth += pActWin->LogicToPixel( aSize ).Width();
-
-        pActWin->SetFont( aOldFont );
-
-        mnPageNumberWidthPixel = nWidth;
-    }
-    return mnPageNumberWidthPixel;
-}
-#endif
-
 // --------------------------------------------------------------------
 
 void OutlineView::UpdateParagraph( USHORT nPara )
@@ -2175,3 +2151,5 @@ OutlineViewPageChangesGuard::~OutlineViewPageChangesGuard()
 
 
 } // end of namespace sd
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
