@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -99,6 +100,7 @@ SdrGrafObj* View::InsertGraphic( const Graphic& rGraphic, sal_Int8& rAction,
     SdrGrafObj*		pNewGrafObj = NULL;
     SdrPageView*	pPV = GetSdrPageView();
     SdrObject*		pPickObj = pObj;
+    const bool bOnMaster = pPV && pPV->GetPage() && pPV->GetPage()->IsMasterPage();
 
     if(pPV && this->ISA(::sd::slidesorter::view::SlideSorterView))
     {
@@ -115,7 +117,7 @@ SdrGrafObj* View::InsertGraphic( const Graphic& rGraphic, sal_Int8& rAction,
     if( mnAction == DND_ACTION_LINK && pPickObj && pPV )
     {
         const bool bIsGraphic = pPickObj->ISA( SdrGrafObj );
-        if( bIsGraphic || pObj->IsEmptyPresObj() )
+        if( bIsGraphic || (pObj->IsEmptyPresObj() && !bOnMaster) )
         {
             if( IsUndoEnabled() )
                 BegUndo(String(SdResId(STR_INSERTGRAPHIC)));	
@@ -631,3 +633,5 @@ SfxStyleSheet* View::GetStyleSheet() const
 }
 
 } // end of namespace sd
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
